( cd usr/lib ; rm -rf libhistory.so.4 )
( cd usr/lib ; ln -sf libhistory.so.4.3 libhistory.so.4 )
( cd usr/lib ; rm -rf libhistory.so )
( cd usr/lib ; ln -sf libhistory.so.4.3 libhistory.so )
( cd usr/lib ; rm -rf libreadline.so.4 )
( cd usr/lib ; ln -sf libreadline.so.4.3 libreadline.so.4 )
( cd usr/lib ; rm -rf libreadline.so )
( cd usr/lib ; ln -sf libreadline.so.4.3 libreadline.so )
